@@ -399,6 +399,8 @@ gnome_bg_set_accountsservice_background (const gchar *background)
 bail:
   if (proxy != NULL)
     g_object_unref (proxy);
+  if (user != NULL)
+    g_object_unref (user);
   if (variant != NULL)
     g_variant_unref (variant);
 }
@@ -625,7 +627,7 @@ gnome_bg_get_filename (GnomeBG *bg)
 }
 
 static inline gchar *
-get_wallpaper_cache_dir ()
+get_wallpaper_cache_dir (void)
 {
 	return g_build_filename (g_get_user_cache_dir(), "wallpaper", NULL);
 }
@@ -2216,7 +2218,7 @@ create_img_thumbnail (GnomeBG                      *bg,
 			SlideShow *show = get_as_slideshow (bg, bg->filename);
 
 			if (show) {
-				double alpha;
+				double alpha=255;
 				Slide *slide;
 
 				if (frame_num == -1)
@@ -2320,8 +2322,17 @@ find_best_size (GSList *sizes, gint width, gint height)
 				best = size;
 			} 
 			else if (d == distance) {
-				if (abs (size->width - width) < abs (best->width - width)) {
-					best = size;
+				if (best == NULL)
+				{
+					if (abs (size->width - width) < abs (width)) {
+						best = size;
+					}
+				}
+				else
+				{
+					if (abs (size->width - width) < abs (best->width - width)) {
+						best = size;
+					}
 				}
 			}
 		}
@@ -2790,6 +2801,8 @@ stack_is (SlideShow *parser,
 		stack = g_list_prepend (stack, (gpointer)s);
 		s = va_arg (args, const char *);
 	}
+
+	va_end (args);
 	
 	l1 = stack;
 	l2 = parser->stack->head;
@@ -2823,7 +2836,12 @@ handle_text (GMarkupParseContext *context,
 	     GError             **err)
 {
 	SlideShow *parser = user_data;
-	Slide *slide = parser->slides->tail? parser->slides->tail->data : NULL;
+
+	g_return_if_fail (parser != NULL);
+	g_return_if_fail (parser->slides != NULL);
+	g_return_if_fail (parser->slides->tail != NULL);
+
+	Slide *slide = parser->slides->tail->data;
 	FileSize *fs;
 	gint i;
 
